@@ -24,15 +24,7 @@
 #ifndef IGRAPH_THREADING_H
 #define IGRAPH_THREADING_H
 
-#undef __BEGIN_DECLS
-#undef __END_DECLS
-#ifdef __cplusplus
-# define __BEGIN_DECLS extern "C" {
-# define __END_DECLS }
-#else
-# define __BEGIN_DECLS /* empty */
-# define __END_DECLS /* empty */
-#endif
+#include "igraph_decls.h"
 
 __BEGIN_DECLS
 
